@@ -16,31 +16,40 @@ function(formu, dat1, fixedEffects, starting, randomEffects, varst, method, chk,
   try(
   withCallingHandlers(
     {
-    mv1 <- nlme(formu,
+    mv1 <- 
+    nlme(formu,
       data= dat1,
       fixed= as.list(fixedEffects),
       start= starting,
       random= randomEffects,
       weights= eval(parse(text=paste("var.function.", substr(analysis[1],1,1), varst, sep=""))),
       method = method)
-    anova(mv1)
+    
+    if(exists("mv1")) mv1$call$model = formu
     }, warning = NlmeIfError), silent=TRUE)
 
-  if(exists("mv1"))
-    {
-    # check lambda parameter for failure
-    a = summary(mv1)
-    a = a$tTable
-    if (chk=="with.lambda")
-      {
-      if (a[4,5] > .05 | a[4,1] < 0)
-        {
-        if (verbose==TRUE) print (a)
-        rm(mv1)
-        if (verbose==TRUE) writeLines("\n ***** failed (lambda p> .05 or lambda < 0) *****\n")
-        }
-      }
-    }
+  #if(exists("mv1"))
+  #  {
+  #  # check lambda parameter for failure
+  #  a = summary(mv1)
+  #  a = a$tTable
+  #  if (chk=="with.lambda")
+  #    {
+  #    print ("a")
+  #    print (a)
+  #    lambdaRows = numeric(0)
+  #    for (i in seq(1,length(lambdaRows))) {
+  #      if (substr(rownames(a)[i],1,7) == "lambda.") lambdaRows[i] = c(lambdaRows, i)
+  #    
+  #    mv1$coefficients$fixed[2] = 0
+  #    if (a[4,5] > .05 | a[4,1] < 0)
+  #      {
+  #      if (verbose==TRUE) print (a)
+  #      rm(mv1)
+  #      if (verbose==TRUE) writeLines("\n ***** failed (lambda p> .05 or lambda < 0) *****\n")
+  #      }
+  #    }
+  #  }
   
   if(exists("mv1")) return(mv1)  
   }
